@@ -17,16 +17,21 @@
 //
 // Alternative licensing terms are available from the licensor.
 // For commercial licensing, see <https://www.artifex.com/> or contact
-// Artifex Software, Inc., 1305 Grant Avenue - Suite 200, Novato,
-// CA 94945, U.S.A., +1(415)492-9861, for further information.
+// Artifex Software, Inc., 39 Mesa Street, Suite 108A, San Francisco,
+// CA 94129, USA, for further information.
 
 #ifndef MUPDF_FITZ_MATH_H
 #define MUPDF_FITZ_MATH_H
 
 #include "mupdf/fitz/system.h"
 
+#include <math.h>
 #include <assert.h>
 
+#ifndef M_PI
+#define M_PI 3.14159265358979323846
+#endif
+
 /**
 	Multiply scaled two integers in the 0..255 range
 */
@@ -85,6 +90,14 @@ int fz_atoi(const char *s);
 */
 int64_t fz_atoi64(const char *s);
 
+/**
+	size_t atoi that copes with NULL.
+
+	NOTE: limited to 63bits. Negative numbers
+	are returned as 0.
+*/
+size_t fz_atoz(const char *s);
+
 /**
 	Some standard math functions, done as static inlines for speed.
 	People with compilers that do not adequately implement inline
@@ -150,6 +163,11 @@ static inline int fz_clampi(int x, int min, int max)
 	return x < min ? min : x > max ? max : x;
 }
 
+static inline int64_t fz_clamp64(int64_t x, int64_t min, int64_t max)
+{
+	return x < min ? min : x > max ? max : x;
+}
+
 static inline double fz_clampd(double x, double min, double max)
 {
 	return x < min ? min : x > max ? max : x;
@@ -529,8 +547,6 @@ fz_matrix fz_transform_page(fz_rect mediabox, float resolution, float rotate);
 /**
 	Create an inverse matrix.
 
-	inverse: Place to store inverse matrix.
-
 	matrix: Matrix to invert. A degenerate matrix, where the
 	determinant is equal to zero, can not be inverted and the
 	original matrix is returned instead.
@@ -542,9 +558,9 @@ fz_matrix fz_invert_matrix(fz_matrix matrix);
 /**
 	Attempt to create an inverse matrix.
 
-	inverse: Place to store inverse matrix.
+	inv: Place to store inverse matrix.
 
-	matrix: Matrix to invert. A degenerate matrix, where the
+	src: Matrix to invert. A degenerate matrix, where the
 	determinant is equal to zero, can not be inverted.
 
 	Returns 1 if matrix is degenerate (singular), or 0 otherwise.
@@ -764,6 +780,24 @@ static inline fz_quad fz_make_quad(
 	return q;
 }
 
+FZ_DATA extern const fz_quad fz_invalid_quad;
+FZ_DATA extern const fz_quad fz_infinite_quad;
+
+/**
+	Is a quad valid?
+*/
+int fz_is_valid_quad(fz_quad q);
+
+/**
+	Is a quad empty?
+*/
+int fz_is_empty_quad(fz_quad q);
+
+/**
+	Is a quad infinite?
+*/
+int fz_is_infinite_quad(fz_quad q);
+
 /**
 	Convert a rect to a quad (losslessly).
 */
