@@ -1,4 +1,4 @@
-// Copyright (C) 2004-2022 Artifex Software, Inc.
+// Copyright (C) 2004-2024 Artifex Software, Inc.
 //
 // This file is part of MuPDF.
 //
@@ -62,6 +62,10 @@ typedef unsigned __int64 uint64_t;
 
 #define nelem(x) (sizeof(x)/sizeof((x)[0]))
 
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
+
 #define FZ_PI 3.14159265f
 #define FZ_RADIAN 57.2957795f
 #define FZ_DEGREE 0.017453292f
@@ -72,12 +76,37 @@ typedef unsigned __int64 uint64_t;
 	Spot architectures where we have optimisations.
 */
 
+/* ARCH_ARM is only used for 32bit ARM stuff. */
 #if defined(__arm__) || defined(__thumb__)
 #ifndef ARCH_ARM
 #define ARCH_ARM
 #endif
 #endif
 
+/* Detect NEON */
+#ifndef ARCH_HAS_NEON
+#if defined(__ARM_NEON) || defined(__ARM_NEON__)
+#define ARCH_HAS_NEON 1
+#endif
+#endif
+
+#ifndef ARCH_HAS_NEON
+#define ARCH_HAS_NEON 0
+#endif
+
+
+/* We assume that pretty much any X86 or X64 machine has SSE these days. */
+#ifndef ARCH_HAS_SSE
+#if defined(_M_IX86) || defined(_M_AMD64) || defined(_M_X64)
+#define ARCH_HAS_SSE 1
+#endif
+#endif
+
+#ifndef ARCH_HAS_SSE
+#define ARCH_HAS_SSE 0
+#endif
+
+
 /**
 	Some differences in libc can be smoothed over
 */
@@ -165,9 +194,6 @@ static __inline int signbit(double x)
 
 #ifdef _WIN32
 
-char *fz_utf8_from_wchar(const wchar_t *s);
-wchar_t *fz_wchar_from_utf8(const char *s);
-
 /* really a FILE* but we don't want to include stdio.h here */
 void *fz_fopen_utf8(const char *name, const char *mode);
 int fz_remove_utf8(const char *name);
@@ -184,6 +210,8 @@ void fz_free_argv(int argc, char **argv);
 
 int64_t fz_stat_ctime(const char *path);
 int64_t fz_stat_mtime(const char *path);
+int fz_mkdir(char *path);
+
 
 /* inline is standard in C++. For some compilers we can enable it within
  * C too. Some compilers think they know better than we do about when
